@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/Solid.pm 66687 2008-07-24T06:18:24.102192Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/Solid.pm 66700 2008-07-24T09:37:48.241728Z daisuke  $
 
 package Google::Chart::Fill::Solid;
 use Moose;
@@ -28,4 +28,16 @@ sub parameter_value {
     return join($self->target, 's', $self->color)
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME
+
+Google::Chart::Fill::Solid - Apply Solid Fill
+
+=head1 METHODS
+
+=head2 parameter_value
+
+=cut
\ No newline at end of file
